@@ -24,8 +24,11 @@ class Maker:
     def run(self, commands, cwd=None):
         if cwd is None:
             cwd = self.cwd
-        rich_print(f"{{bold}}$ cd {cwd}\n$ " + join(commands), color="green")
-        run(commands, cwd=cwd)
+        eol = "\n"
+        if os.name == "nt":
+            eol = "\r" + eol
+        rich_print(f"{{bold}}$ cd {cwd}{eol}$ " + join(commands), color="green")
+        run(commands, cwd=cwd, check=True)
 
     def init(self):
         text = ""
